desktop/win32/source/loader.cxx |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit c84e8a14e476a70989e66df142e7b2426df02617
Author:     Stephan Bergmann <stephan.bergm...@allotropia.de>
AuthorDate: Tue Jan 16 14:55:03 2024 +0100
Commit:     Stephan Bergmann <stephan.bergm...@allotropia.de>
CommitDate: Mon Feb 12 20:37:52 2024 +0100

    Search for load-time variables in fundamental.override.ini
    
    ...instead of arbitrarily cramming them into bootstrap.ini.  (And don't 
force
    those ini-files to have an additional [Win32] section, when
    include/rtl/bootstrap.h demands that "An ini-file is only allowed to have 
one
    section, which must be named `[Bootstrap]` with the square brackets.")
    
    Change-Id: I732bf9d771ea309eccd35b6db0f565a0c56a3c3e
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/162188
    Tested-by: Stephan Bergmann <stephan.bergm...@allotropia.de>
    Reviewed-by: Stephan Bergmann <stephan.bergm...@allotropia.de>
    (cherry picked from commit 50b14f26de63d22b9ad05ca51d9edc53e024e75e)
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/163252
    Tested-by: Jenkins

diff --git a/desktop/win32/source/loader.cxx b/desktop/win32/source/loader.cxx
index b730d4119695..998eb189effc 100644
--- a/desktop/win32/source/loader.cxx
+++ b/desktop/win32/source/loader.cxx
@@ -215,11 +215,11 @@ int officeloader_impl(bool bAllowConsole)
     bool fSuccess = false;
     bool bFirst = true;
 
     // read limit values from bootstrap.ini
     unsigned int nMaxMemoryInMB = 0;
     bool bExcludeChildProcesses = true;
 
-    const WCHAR* szIniFile = L"\bootstrap.ini";
+    const WCHAR* szIniFile = L"\fundamental.override.ini";
     const size_t nDirLen = wcslen(szIniDirectory);
     if (wcslen(szIniFile) + nDirLen < MAX_PATH)
     {
@@ -232,8 +232,8 @@ int officeloader_impl(bool bAllowConsole)
             boost::property_tree::ptree pt;
             std::ifstream aFile(szBootstrapIni);
             boost::property_tree::ini_parser::read_ini(aFile, pt);
-            nMaxMemoryInMB = pt.get("Win32.LimitMaximumMemoryInMB", 
nMaxMemoryInMB);
-            bExcludeChildProcesses = 
pt.get("Win32.ExcludeChildProcessesFromLimit", bExcludeChildProcesses);
+            nMaxMemoryInMB = pt.get("Bootstrap.LimitMaximumMemoryInMB", 
nMaxMemoryInMB);
+            bExcludeChildProcesses = 
pt.get("Bootstrap.ExcludeChildProcessesFromLimit", bExcludeChildProcesses);
         }
         catch (...)
@@ -215,11 +215,11 @@ int officeloader_impl(bool bAllowConsole)
     bool bFirst = true;
 
-    // read limit values from bootstrap.ini
+    // read limit values from fundamental.override.ini
     unsigned int nMaxMemoryInMB = 0;
     bool bExcludeChildProcesses = true;
         {

Reply via email to